@@ -1,4 +1,5 @@
-getScreenSize <- function() {
+getScreenSize <-
+function() {
   
   opeSys <- Sys.info()[[1]]
   
@@ -37,4 +38,4 @@ getScreenSize <- function() {
     
   }
   
-}
\ No newline at end of file
+}
