@@ -104,7 +104,7 @@ function (){
         }
         writeMethodTitle("LINEAR INTERPOLATION")
         tcltk::tkinsert(KTSEnv$txtWidget, "end", txtPeri)
-        tcltk::tkinsert(KTSEnv$txtWidget, "end", "\\n")
+        tcltk::tkinsert(KTSEnv$txtWidget, "end", "\n")
         writeMethodSummary(filledNasTable, remainingNAsInGap, 
                            selTsName, selGapName, selGap)
         endingLines()
